@@ -265,7 +265,8 @@ class TickerDax:
                     uri,
                     extra_headers={'email': self._email, 'token': self._websocket_api_key}
             ) as connected_socket:
-                self._logger.info(f"> Connected to {uri}")
+                now = datetime.now(tz=timezone.utc).strftime('%Y-%m-%dT%H:%M:%S')
+                self._logger.info(f' [{now}] > Connected to {uri}')
                 while True:
                     data = json.loads(await connected_socket.recv())
                     symbol = data.get('symbol')
@@ -277,6 +278,7 @@ class TickerDax:
 
         except (ConnectionClosed, ConnectionClosedOK) as error:
             self._logger.error(error)
+            self._logger.info('Trying to reconnect...')
             # re-connect if the connection was closed
             await self._stream_to_cache(route, symbols)
 
